@@ -13,9 +13,12 @@ typedef Eo Efl_Ui_Box;
 
 
 #endif
+/** Efl UI box class
+ *
+ * @ingroup Efl_Ui_Box
+ */
 #define EFL_UI_BOX_CLASS efl_ui_box_class_get()
 
-EWAPI const Eo_Class *efl_ui_box_class_get(void);
-
+EWAPI const Efl_Class *efl_ui_box_class_get(void);
 
 #endif
