@@ -13,9 +13,12 @@ typedef Eo Elm_Ctxpopup_Internal_Part;
 
 
 #endif
+/** Elementary contex popup internal part class
+ *
+ * @ingroup Elm_Ctxpopup_Internal_Part
+ */
 #define ELM_CTXPOPUP_INTERNAL_PART_CLASS elm_ctxpopup_internal_part_class_get()
 
-EWAPI const Eo_Class *elm_ctxpopup_internal_part_class_get(void);
-
+EWAPI const Efl_Class *elm_ctxpopup_internal_part_class_get(void);
 
 #endif
