@@ -13,9 +13,12 @@ typedef Eo Elm_Gengrid_Pan;
 
 
 #endif
+/** Elementary gengrid pan class
+ *
+ * @ingroup Elm_Gengrid_Pan
+ */
 #define ELM_GENGRID_PAN_CLASS elm_gengrid_pan_class_get()
 
-EWAPI const Eo_Class *elm_gengrid_pan_class_get(void);
-
+EWAPI const Efl_Class *elm_gengrid_pan_class_get(void);
 
 #endif
